#[non_exhaustive]pub enum RexLoggerError {
InitializationError {
reason: String,
source: Option<Box<dyn SourceError + Send + Sync>>,
},
Other(Error),
}Expand description
Represents errors that can occur during Rex logger operations.
This enum provides specific error variants for different types of failures that can occur during logging operations
Variants
InitializationError- Error during logger initializationOther-Anyhowfor other errors
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InitializationError
Error indicating an initialization error
Fields
reason- Description of errorsource- Underlying error that caused the failure
Other(Error)
Anyhow for other errors