pub struct RhaiContext {
pub rhai_api_name: Option<String>,
pub line_number: u32,
}Expand description
Represents the execution context of a Rhai script function.
Fields
function_name- The name of the Rhai function currently being executedline_number- The line number in the script where execution is occurring
Fields
rhai_api_name: Option<String>line_number: u32Trait Implementations
Sourceimpl Clone for RhaiContext
impl Clone for RhaiContext
Sourcefn clone(&self) -> RhaiContext
fn clone(&self) -> RhaiContext
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for RhaiContext
impl RefUnwindSafe for RhaiContext
impl Send for RhaiContext
impl Sync for RhaiContext
impl Unpin for RhaiContext
impl UnsafeUnpin for RhaiContext
impl UnwindSafe for RhaiContext